## 结算参数

接口：fut_settle

描述：获取每日结算参数数据，包括交易和交割费率等

限量：单次最大返回1600行数据，可根据日期循环，总量不限制

积分：用户需要至少2000积分才可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | N | 交易日期 （trade_date/ts_code至少需要输入一个参数） |
| ts_code | str | N | 合约代码 |
| start_date | str | N | 开始日期(YYYYMMDD格式，下同) |
| end_date | str | N | 结束日期 |
| exchange | str | N | 交易所代码 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 合约代码 |
| trade_date | str | Y | 交易日期 |
| settle | float | Y | 结算价 |
| trading_fee_rate | float | Y | 交易手续费率 |
| trading_fee | float | Y | 交易手续费 |
| delivery_fee | float | Y | 交割手续费 |
| b_hedging_margin_rate | float | Y | 买套保交易保证金率 |
| s_hedging_margin_rate | float | Y | 卖套保交易保证金率 |
| long_margin_rate | float | Y | 买投机交易保证金率 |
| short_margin_rate | float | Y | 卖投机交易保证金率 |
| offset_today_fee | float | N | 平今仓手续率 |
| exchange | str | N | 交易所 |

接口示例

```python
pro = ts.pro_api('your token')

df = pro.fut_settle(trade_date='20181114', exchange='SHFE')
```

数据示例

```python
ts_code     trade_date    settle  trading_fee_rate  trading_fee  \
0    CU1811.SHF   20181114  48840.00             0.050           0.0   
```